from __future__ import annotations

import hypercorn.config
import hypercorn.trio.run
import hypercorn.utils

import capport.config


def run(config: hypercorn.config.Config) -> None:
    sockets = config.create_sockets()
    assert config.worker_class == 'trio'

    hypercorn.trio.run.trio_worker(config=config, sockets=sockets)

    for sock in sockets.secure_sockets:
        sock.close()
    for sock in sockets.insecure_sockets:
        sock.close()


def main() -> None:
    _config = capport.config.Config.load_default_once()

    hypercorn_config = hypercorn.config.Config()
    hypercorn_config.application_path = 'capport.api.app'
    hypercorn_config.worker_class = 'trio'

    if _config.server_names:
        hypercorn_config.server_names = _config.server_names
    elif not _config.debug:
        raise Exception(
            "production setup requires server-names in config (list of accepted hostnames in http requests)"
        )

    run(hypercorn_config)
